Crate diskann_benchmark_runner

Crate diskann_benchmark_runner 

A moderately functional utility for making simple benchmarking CLI applications.

Re-exports

pub use any::Any;
pub use app::App;
pub use benchmark::Benchmark;
pub use input::Input;
pub use output::Output;

Modules

any
app
The CLI frontend for benchmark applications built with this crate.
benchmark
dispatcher
Dispatch Rules
files
input
output
registry
utils

Macros

describeln
Used in DispatchRule::description(f, _) to ensure that additional description lines are properly aligned.

Structs

Checker
Shared context for resolving input and output files paths post deserialization.
Checkpoint
A helper to generate incremental snapshots of data while a benchmark is progressing.

Traits

CheckDeserialization
Perform post-process resolution of input and output files paths.