Check

Enum Check 

pub enum Check {
    Skeleton,
    Tolerances {
        describe: Option<String>,
    },
    Verify {
        tolerances: PathBuf,
        input_file: PathBuf,
    },
    Run {
        tolerances: PathBuf,
        input_file: PathBuf,
        before: PathBuf,
        after: PathBuf,
        output_file: Option<PathBuf>,
    },
}
Subcommands for regression check operations.

Variants



Skeleton

Provide a skeleton of the overall tolerance files.



Tolerances

List all the tolerance inputs accepted by the benchmark executable.

Fields

describe: Option<String>

Describe the layout for the named tolerance kind.



Verify

Verify the tolerance file with the accompanying input file.

Fields

tolerances: PathBuf

The tolerance file to check.

input_file: PathBuf

The benchmark input file used to generate the data that will be compared.



Run

Run regression checks against before/after output files.

Fields

tolerances: PathBuf

The tolerance file to check.

input_file: PathBuf

The benchmark input file used to generate the data that will be compared.

before: PathBuf

The --output-file from a benchmark to use as a baseline.

after: PathBuf

The --output-file that will be checked for regression against before.

output_file: Option<PathBuf>

Optional path to write the JSON check results.