Commands

Enum Commands 

pub enum Commands {
    Inputs {
        describe: Option<String>,
    },
    Benchmarks {},
    Skeleton,
    Run {
        input_file: PathBuf,
        output_file: PathBuf,
        dry_run: bool,
    },
}
Parsed command line options.

Variants



Inputs

List the kinds of input formats available for ingestion.

Fields

describe: Option<String>

Describe the layout of the named input kind.



Benchmarks

List the available benchmarks.



Skeleton

Provide a skeleton JSON file for running a set of benchmarks.



Run

Run a list of benchmarks.

Fields

input_file: PathBuf

The input file to run.

output_file: PathBuf

The path where the output file should reside.

dry_run: bool

Parse an input file and perform all validation checks, but don’t actually run any benchmarks.