App

Struct App 

pub struct App { /* private fields */ }
The CLI used to drive a benchmark application.

Implementations

Source

impl App

pub fn parse() -> Self

Construct Self by parsing commandline arguments from [std::env::args].

This simply redirects to clap::Parser::parse and is provided to allow parsing without the clap::Parser trait in scope.

pub fn try_parse_from<I, T>(itr: I) -> Result<Self>
where I: IntoIterator<Item = T>, T: Into<OsString> + Clone,

Construct Self by parsing command line arguments from the iterator.

This simply redirects to clap::Parser::try_parse_from and is provided to allow parsing without the clap::Parser trait in scope.

pub fn from_commands(command: Commands) -> Self

Construct Self directly from a Commands enum.

pub fn run( &self, inputs: &Inputs, benchmarks: &Benchmarks, output: &mut dyn Output, ) -> Result<()>

Run the application using the registered inputs and outputs.