pub struct MatchContext { /* private fields */ }Expand description
Context for Benchmark::try_match.
This is used to create matching Scores via Self::success and Self::fail.
Users can test their Benchmark::try_match implementations using Self::test.
Internally, the MatchContext decides whether or not failure reasons are evaluated,
eliding formatting in situations where the results will not be used.
Implementations
Sourceimpl MatchContext
impl MatchContext
Sourcepub fn success(&self, score: u32) -> Score
pub fn success(&self, score: u32) -> Score
Create a new Score configured for “success” with the given score.
Lower scores indicate better successful matches.