pub struct MatchScore(pub u32);Expand description
Successful matches from Benchmark::try_match will return MatchScores.
A lower numerical value indicates a better match for purposes of overload resolution.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for MatchScore
impl Clone for MatchScore
Sourcefn clone(&self) -> MatchScore
fn clone(&self) -> MatchScore
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchScore
impl Debug for MatchScore
Sourceimpl Display for MatchScore
impl Display for MatchScore
Sourceimpl Ord for MatchScore
impl Ord for MatchScore
Sourcefn cmp(&self, other: &MatchScore) -> Ordering
fn cmp(&self, other: &MatchScore) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MatchScore
impl PartialEq for MatchScore
Sourcefn eq(&self, other: &MatchScore) -> bool
fn eq(&self, other: &MatchScore) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MatchScore
impl PartialOrd for MatchScore
impl Copy for MatchScore
impl Eq for MatchScore
impl StructuralPartialEq for MatchScore