Score

Struct Score 

pub struct Score { /* private fields */ }
A score for Benchmark::try_match.

A Score is in one of two states: success or failure. Lower scores indicate better matches in both states. In the failure case, scores rank “near misses” for diagnostics.

The current state can be queried with Score::is_success.

Implementations

Source

impl Score

pub fn penalize(&mut self, by: u32)

If the score is in the “success” state, penalize it by by.

Has no effect if the score is already in the “failure” state.

pub fn fail(&mut self, by: u32, reason: &dyn Display)

Transition the score to the “failure” state with penalty by and a reason.

If the score is already in the “failure” state, by is added to the existing failure score and reason is appended to the list of failure reasons.

pub fn is_success(&self) -> bool

Return true if self is in the “success” state. Returning false implies the “failure” state.