pub struct FailureScore(pub u32);Expand description
Successful matches from DispatchRule will return FailureScores.
A lower numerical value indicates a better match, which can help when compiling a list of considered and rejected candidates.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for FailureScore
impl Clone for FailureScore
Sourcefn clone(&self) -> FailureScore
fn clone(&self) -> FailureScore
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FailureScore
impl Debug for FailureScore
Sourceimpl Display for FailureScore
impl Display for FailureScore
Sourceimpl Ord for FailureScore
impl Ord for FailureScore
Sourcefn cmp(&self, other: &FailureScore) -> Ordering
fn cmp(&self, other: &FailureScore) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FailureScore
impl PartialEq for FailureScore
Sourceimpl PartialOrd for FailureScore
impl PartialOrd for FailureScore
impl Copy for FailureScore
impl Eq for FailureScore
impl StructuralPartialEq for FailureScore