Module output

Module output 

Structs

DefaultOutput
A default output that sends:
Memory
The Memory allows test output to be captured directly in a buffer.
Sink
An output that suppresses all prints and progress bars.

Traits

Output
To enable testing and output redirection, the output stream that tests print to is hidden behind this Output trait, which consists of two parts:

Functions

default
Return the default implementation of Output that sends: