pub struct Memory(/* private fields */);Expand description
The Memory allows test output to be captured directly in a buffer.
Integration tests can use this so each tests runs in its own environment.
Progress bars are suppressed.
Implementations