Output

Trait Output 

pub trait Output {
    // Required methods
    fn sink(&mut self) -> &mut dyn Write;
    fn draw_target(&self) -> ProgressDrawTarget;
}
To enable testing and output redirection, the output stream that tests print to is hidden behind this Output trait, which consists of two parts:

  • sink: A &mut dyn std::io::Write which is the target for all test prints.
  • draw_target: The target that all progress bars should use.

Required Methods

fn sink(&mut self) -> &mut dyn Write

fn draw_target(&self) -> ProgressDrawTarget