Inputs

Struct Inputs 

pub struct Inputs { /* private fields */ }
A collection of crate::Input.

Implementations

Source

impl Inputs

pub fn new() -> Self

Construct a new empty Inputs registry.

pub fn get(&self, tag: &str) -> Option<&dyn Input>

Return the input with the registerd tag if present. Otherwise, return None.

pub fn register<T>(&mut self, input: T) -> Result<()>
where T: Input + 'static,

Register input in the registry.

Returns an error if any other input with the same Input::tag() has been registered while leaving the underlying registry unchanged.

pub fn tags(&self) -> impl ExactSizeIterator<Item = &'static str> + use<'_>

Return an iterator over all registered input tags in an unspecified order.