Mismatch

Struct Mismatch 

pub struct Mismatch { /* private fields */ }
Document the reason for a method mathing failure.

Implementations

Source

impl Mismatch

pub fn method(&self) -> &str

Return the name of the benchmark that we failed to match.

pub fn reason(&self) -> &str

Return the reason why this method was not a match.