pub struct Indent<'a> { /* private fields */ }Expand description
Indents each line of a string by a fixed number of spaces.
Each line is prefixed with spaces spaces and terminated with a newline.
Examples
use diskann_benchmark_runner::utils::fmt::Indent;
let indented = Indent::new("hello\nworld", 4).to_string();
assert_eq!(indented, " hello\n world\n");Implementations