Module num

Module num 

Number utilities for enforcing deserialization constraints and computing relative errors.

Structs

NonNegativeFinite
A finite floating-point value that is greater than or equal to zero.

Enums

InvalidNonNegativeFinite
Error returned when attempting to construct a NonNegativeFinite.
RelativeChangeError
Error returned when attempting to compute a relative change.

Functions

relative_change
Compute the relative change from before to after.