pub enum Check {
Skeleton,
Tolerances {
describe: Option<String>,
},
Verify {
tolerances: PathBuf,
input_file: PathBuf,
},
Run {
tolerances: PathBuf,
input_file: PathBuf,
before: PathBuf,
after: PathBuf,
output_file: Option<PathBuf>,
},
}Expand description
Subcommands for regression check operations.
Variants
Skeleton
Provide a skeleton of the overall tolerance files.
Tolerances
List all the tolerance inputs accepted by the benchmark executable.
Verify
Verify the tolerance file with the accompanying input file.
Fields
Run
Run regression checks against before/after output files.
Fields