Structs
- Default
Output - A default output that sends:
- Memory
- The
Memoryallows test output to be captured directly in a buffer. - Sink
- An output that suppresses all prints and progress bars.
Traits
- Output
- To enable testing and output redirection, the output stream that tests print to is hidden
behind this
Outputtrait, which consists of two parts: