pub struct Benchmarks { /* private fields */ }Expand description
A collection of registerd benchmarks.
Implementations
Sourceimpl Benchmarks
impl Benchmarks
Sourcepub fn register<T>(
&mut self,
name: impl Into<String>,
benchmark: impl Fn(T::Type<'_>, Checkpoint<'_>, &mut dyn Output) -> Result<Value> + 'static,
)
pub fn register<T>( &mut self, name: impl Into<String>, benchmark: impl Fn(T::Type<'_>, Checkpoint<'_>, &mut dyn Output) -> Result<Value> + 'static, )
Register a new benchmark with the given name.
The type parameter T is used to match this benchmark with a registered
crate::Any, which is determined using by <T as DispatchRule<&Any>>.
Sourcepub fn has_match(&self, job: &Any) -> bool
pub fn has_match(&self, job: &Any) -> bool
Return true if job matches with any registerd benchmark. Otherwise, return false.
Sourcepub fn call(
&self,
job: &Any,
checkpoint: Checkpoint<'_>,
output: &mut dyn Output,
) -> Result<Value>
pub fn call( &self, job: &Any, checkpoint: Checkpoint<'_>, output: &mut dyn Output, ) -> Result<Value>
Attempt to the best matching benchmark for job - forwarding the checkpoint and
output to the benchmark.
Returns the results of the benchmark if successful.
Errors if a suitable method could not be found or if the invoked benchmark failed.
Sourcepub fn debug(&self, job: &Any, methods: usize) -> Result<(), Vec<Mismatch>>
pub fn debug(&self, job: &Any, methods: usize) -> Result<(), Vec<Mismatch>>
Attempt to debug reasons for a missed dispatch, returning at most methods reasons.
This implementation works by invoking DispatchRule::try_match with
job on all registered benchmarks. If no successful matches are found, the lowest
ranking crate::dispatcher::FailureScores are collected and used to report details
of the nearest misses using DispatchRule::description.
Returns Ok(()) is a match was found.