pub struct Benchmarks { /* private fields */ }Expand description
A collection of registered benchmarks.
Implementations
Sourceimpl Benchmarks
impl Benchmarks
Sourcepub fn register<T>(&mut self, name: impl Into<String>, benchmark: T)where
T: Benchmark,
pub fn register<T>(&mut self, name: impl Into<String>, benchmark: T)where
T: Benchmark,
Register a new benchmark with the given name.
Sourcepub fn has_match(&self, job: &Any) -> bool
pub fn has_match(&self, job: &Any) -> bool
Return true if job matches with any registered benchmark. Otherwise, return false.
Sourcepub fn call(
&self,
job: &Any,
checkpoint: Checkpoint<'_>,
output: &mut dyn Output,
) -> Result<Value>
pub fn call( &self, job: &Any, checkpoint: Checkpoint<'_>, output: &mut dyn Output, ) -> Result<Value>
Attempt to run the best matching benchmark for job.
Returns the results of the benchmark if successful.
Errors if a suitable method could not be found or if the invoked benchmark failed.
Sourcepub fn debug(&self, job: &Any, max_methods: usize) -> Result<(), Vec<Mismatch>>
pub fn debug(&self, job: &Any, max_methods: usize) -> Result<(), Vec<Mismatch>>
Attempt to debug reasons for a missed dispatch, returning at most max_methods
reasons.
Returns Ok(()) if a match was found.
Sourcepub fn register_regression<T>(&mut self, name: impl Into<String>, benchmark: T)where
T: Regression,
pub fn register_regression<T>(&mut self, name: impl Into<String>, benchmark: T)where
T: Regression,
Register a regression-checkable benchmark with the associated name.
Upon registration, the associated Regression::Tolerances input and the benchmark
itself will be reachable via Check.