pub struct Inputs { /* private fields */ }Expand description
A collection of crate::Input.
Implementations
Sourceimpl Inputs
impl Inputs
Sourcepub fn get(&self, tag: &str) -> Option<&dyn Input>
pub fn get(&self, tag: &str) -> Option<&dyn Input>
Return the input with the registerd tag if present. Otherwise, return None.
Sourcepub fn register<T>(&mut self, input: T) -> Result<()>where
T: Input + 'static,
pub fn register<T>(&mut self, input: T) -> Result<()>where
T: Input + 'static,
Register input in the registry.
Returns an error if any other input with the same Input::tag() has been registered
while leaving the underlying registry unchanged.
Return an iterator over all registered input tags in an unspecified order.