Checker

Struct Checker 

pub struct Checker { /* private fields */ }
Shared context for resolving input and output files paths post deserialization.

Implementations

Source

impl Checker

pub fn any<T>(&mut self, value: T) -> Result<Any>
where T: Serialize + CheckDeserialization + Debug + 'static,

Invoke CheckDeserialization on value and if successful, package it in Any.

pub fn search_directories(&self) -> &[PathBuf]

Return the ordered list of search directories registered with the Checker.

pub fn output_directory(&self) -> Option<&PathBuf>

Return the output directory registered with the Checker, if any.

pub fn register_output(&mut self, save_path: Option<&Path>) -> Result<PathBuf>

Register save_path as an output directory and resolve save_path to an absolute path.

NOTE

The behavior of this function is expected to change in the near future.

pub fn check_path(&self, path: &Path) -> Result<PathBuf, Error>

Try to resolve path using the following approach:

  1. If path is absolute - check that it exists and is a valid file. If successful, return path unaltered.

  2. If path is relative, work through self.search_directories() in order, returning the absolute path first existing file.