Checkpoint

Struct Checkpoint 

pub struct Checkpoint<'a> { /* private fields */ }
A helper to generate incremental snapshots of data while a benchmark is progressing.

Benchmark implementations may use this to save results as they become available rather than waiting until the end.

Implementations

Source

impl<'a> Checkpoint<'a>

pub fn save(&self) -> Result<()>

Atomically save the zip of the inputs and results to the configured path.

pub fn checkpoint<T: Serialize + ?Sized>(&self, partial: &T) -> Result<()>

Treat partial as a new partial result for the current contents of the checkpoint.

All previously generated results will be saved and partial will be grouped at the input at self.inner.results.len() + 1.

This function should only be called if self is not full (as in, there is at least one input that does not have a corresponding result.