pub struct Delimit<'a, I> { /* private fields */ }Expand description
Formats an iterator with a delimiter between items and optional overrides for the final delimiter and pair formatting.
This is a single-use wrapper: the iterator is consumed on the first call to Display::fmt.
Subsequent calls will print <missing>.
Use Delimit::with_last to change the delimiter before the final item
(e.g., ", and "), which is useful for natural-language lists like
"a, b, and c".
Use Delimit::with_pair to change formatting when there are only two items.
Examples
use diskann_benchmark_runner::utils::fmt::Delimit;
let d = Delimit::new(["a", "b", "c"], ", ").with_last(", and ");
assert_eq!(d.to_string(), "a, b, and c");
let d = Delimit::new(["a", "b"], ", ").with_last(", and ");
assert_eq!(d.to_string(), "a, and b");
let d = Delimit::new(["a", "b"], ", ")
.with_last(", and ")
.with_pair(" and ");
assert_eq!(d.to_string(), "a and b");Implementations
Sourceimpl<'a, I> Delimit<'a, I>
impl<'a, I> Delimit<'a, I>
Sourcepub fn new(itr: impl IntoIterator<IntoIter = I>, delimiter: &'a str) -> Self
pub fn new(itr: impl IntoIterator<IntoIter = I>, delimiter: &'a str) -> Self
Create a new Delimit from an iterable and a delimiter.
By default, the same delimiter is used between every item. Use
Self::with_last and Self::with_pair to opt into special handling
before the final item or for pairs.