Indent

Struct Indent 

pub struct Indent<'a> { /* private fields */ }
Indents each line of a string by a fixed number of spaces.

Each line is prefixed with spaces spaces and terminated with a newline.

Examples

use diskann_benchmark_runner::utils::fmt::Indent;

let indented = Indent::new("hello\nworld", 4).to_string();
assert_eq!(indented, "    hello\n    world\n");

Implementations

Source

impl<'a> Indent<'a>

pub fn new(string: &'a str, spaces: usize) -> Self

Create a new Indent that will prefix each line of string with spaces spaces.